@@ -1,9 +1,15 @@
 package WWW::Google::SiteMap::Index;
-use vars qw($VERSION); $VERSION = '1.08';
+use vars qw($VERSION); $VERSION = '1.10';
 
 =head1 NAME
 
-WWW::Google::SiteMap::Index - Perl extension for managing Google SiteMap Indexes
+WWW::Google::SiteMap::Index - DEPRECATED - See Search::Sitemap
+
+=head1 DEPRECATED
+
+Now that more search engines than just Google are supporting the Sitemap
+protocol, the WWW::Google::SiteMap module has been renamed to
+L<Search::Sitemap>.
 
 =head1 SYNOPSIS
 
